==> client-java-api-4.0.0-sources.jar: io/kubernetes/client/models/V1beta1MutatingWebhookConfigurationFluent.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.kubernetes.client.fluent.Predicate;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface V1beta1MutatingWebhookConfigurationFluent<A extends V1beta1MutatingWebhookConfigurationFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public V1ObjectMeta getMetadata();
    public V1ObjectMeta buildMetadata();
    public A withMetadata(V1ObjectMeta metadata);
    public Boolean hasMetadata();
    public V1beta1MutatingWebhookConfigurationFluent.MetadataNested<A> withNewMetadata();
    public V1beta1MutatingWebhookConfigurationFluent.MetadataNested<A> withNewMetadataLike(V1ObjectMeta item);
    public V1beta1MutatingWebhookConfigurationFluent.MetadataNested<A> editMetadata();
    public V1beta1MutatingWebhookConfigurationFluent.MetadataNested<A> editOrNewMetadata();
    public V1beta1MutatingWebhookConfigurationFluent.MetadataNested<A> editOrNewMetadataLike(V1ObjectMeta item);
    public A addToWebhooks(int index,V1beta1Webhook item);
    public A setToWebhooks(int index,V1beta1Webhook item);
    public A addToWebhooks(V1beta1Webhook... items);
    public A addAllToWebhooks(Collection<V1beta1Webhook> items);
    public A removeFromWebhooks(V1beta1Webhook... items);
    public A removeAllFromWebhooks(Collection<V1beta1Webhook> items);
    
/**
 * This method has been deprecated, please use method buildWebhooks instead.
 * @return The buildable object.
 */
@Deprecated public List<V1beta1Webhook> getWebhooks();
    public List<V1beta1Webhook> buildWebhooks();
    public V1beta1Webhook buildWebhook(int index);
    public V1beta1Webhook buildFirstWebhook();
    public V1beta1Webhook buildLastWebhook();
    public V1beta1Webhook buildMatchingWebhook(io.kubernetes.client.fluent.Predicate<V1beta1WebhookBuilder> predicate);
    public A withWebhooks(List<V1beta1Webhook> webhooks);
    public A withWebhooks(V1beta1Webhook... webhooks);
    public Boolean hasWebhooks();
    public V1beta1MutatingWebhookConfigurationFluent.WebhooksNested<A> addNewWebhook();
    public V1beta1MutatingWebhookConfigurationFluent.WebhooksNested<A> addNewWebhookLike(V1beta1Webhook item);
    public V1beta1MutatingWebhookConfigurationFluent.WebhooksNested<A> setNewWebhookLike(int index,V1beta1Webhook item);
    public V1beta1MutatingWebhookConfigurationFluent.WebhooksNested<A> editWebhook(int index);
    public V1beta1MutatingWebhookConfigurationFluent.WebhooksNested<A> editFirstWebhook();
    public V1beta1MutatingWebhookConfigurationFluent.WebhooksNested<A> editLastWebhook();
    public V1beta1MutatingWebhookConfigurationFluent.WebhooksNested<A> editMatchingWebhook(io.kubernetes.client.fluent.Predicate<V1beta1WebhookBuilder> predicate);

    public interface MetadataNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1ObjectMetaFluent<V1beta1MutatingWebhookConfigurationFluent.MetadataNested<N>>{

        
    public N and();    public N endMetadata();
}
    public interface WebhooksNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1beta1WebhookFluent<V1beta1MutatingWebhookConfigurationFluent.WebhooksNested<N>>{

        
    public N and();    public N endWebhook();
}


}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V1beta1MutatingWebhookConfigurationFluent.java <==
package io.kubernetes.client.models;

import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.kubernetes.client.fluent.Predicate;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface V1beta1MutatingWebhookConfigurationFluent<A extends V1beta1MutatingWebhookConfigurationFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public V1ObjectMeta getMetadata();
    public V1ObjectMeta buildMetadata();
    public A withMetadata(V1ObjectMeta metadata);
    public Boolean hasMetadata();
    public V1beta1MutatingWebhookConfigurationFluent.MetadataNested<A> withNewMetadata();
    public V1beta1MutatingWebhookConfigurationFluent.MetadataNested<A> withNewMetadataLike(V1ObjectMeta item);
    public V1beta1MutatingWebhookConfigurationFluent.MetadataNested<A> editMetadata();
    public V1beta1MutatingWebhookConfigurationFluent.MetadataNested<A> editOrNewMetadata();
    public V1beta1MutatingWebhookConfigurationFluent.MetadataNested<A> editOrNewMetadataLike(V1ObjectMeta item);
    public A addToWebhooks(int index,V1beta1Webhook item);
    public A setToWebhooks(int index,V1beta1Webhook item);
    public A addToWebhooks(V1beta1Webhook... items);
    public A addAllToWebhooks(Collection<V1beta1Webhook> items);
    public A removeFromWebhooks(V1beta1Webhook... items);
    public A removeAllFromWebhooks(Collection<V1beta1Webhook> items);
    
/**
 * This method has been deprecated, please use method buildWebhooks instead.
 * @return The buildable object.
 */
@Deprecated public List<V1beta1Webhook> getWebhooks();
    public List<V1beta1Webhook> buildWebhooks();
    public V1beta1Webhook buildWebhook(int index);
    public V1beta1Webhook buildFirstWebhook();
    public V1beta1Webhook buildLastWebhook();
    public V1beta1Webhook buildMatchingWebhook(io.kubernetes.client.fluent.Predicate<V1beta1WebhookBuilder> predicate);
    public Boolean hasMatchingWebhook(io.kubernetes.client.fluent.Predicate<V1beta1WebhookBuilder> predicate);
    public A withWebhooks(List<V1beta1Webhook> webhooks);
    public A withWebhooks(V1beta1Webhook... webhooks);
    public Boolean hasWebhooks();
    public V1beta1MutatingWebhookConfigurationFluent.WebhooksNested<A> addNewWebhook();
    public V1beta1MutatingWebhookConfigurationFluent.WebhooksNested<A> addNewWebhookLike(V1beta1Webhook item);
    public V1beta1MutatingWebhookConfigurationFluent.WebhooksNested<A> setNewWebhookLike(int index,V1beta1Webhook item);
    public V1beta1MutatingWebhookConfigurationFluent.WebhooksNested<A> editWebhook(int index);
    public V1beta1MutatingWebhookConfigurationFluent.WebhooksNested<A> editFirstWebhook();
    public V1beta1MutatingWebhookConfigurationFluent.WebhooksNested<A> editLastWebhook();
    public V1beta1MutatingWebhookConfigurationFluent.WebhooksNested<A> editMatchingWebhook(io.kubernetes.client.fluent.Predicate<V1beta1WebhookBuilder> predicate);

    public interface MetadataNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1ObjectMetaFluent<V1beta1MutatingWebhookConfigurationFluent.MetadataNested<N>>{

        
    public N and();    public N endMetadata();
}
    public interface WebhooksNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1beta1WebhookFluent<V1beta1MutatingWebhookConfigurationFluent.WebhooksNested<N>>{

        
    public N and();    public N endWebhook();
}


}
